---
layout: post
author:
    name: Steve Gill
    url: https://twitter.com/stevesgill
title:  "Apache Cordova 3.6"
categories: announcements
tags: news releases
---

We are happy to announce that `Apache Cordova 3.6` has been released!

Most notable changes include:

  * Android and Amazon FireOS platforms include a new whitelist for controlling the launch of external applications via intents. Also support for gradle was added.
  * [CB-6761](https://issues.apache.org/jira/browse/CB-6761) Android: Fix native->JS bridge ceasing to fire when page changes and online is set to false and the JS loads quickly
  * Windows8 platform is now called Windows to indicate the support for windows universal apps. The windows8/windows platform now supports building apps targeting Windows 8.1 and Windows Phone 8.1 in addition to Windows 8 which was originally supported (see documentation for new --win and --phone Command Line switches). 
  * For targeting Windows Phone 8.0, the wp8 is still supported. 
  * Support for Windows Universal Apps is being added.
  
To upgrade: (replace `android` with the platform you want to update):

    npm install -g cordova
    cd my_project
    cordova platform update android
    
For non-CLI projects or for pre-3.0 projects, refer to the [upgrade guides](http://cordova.apache.org/docs/en/3.6.0/guide_platforms_index.md.html).

## If this is 3.6.3, where are 3.6.0, 3.6.1, and 3.6.2?

While preparing the 3.6.0 release,
the release candidates were published to a write-once repository.
When it was discovered that the release candidates needed to be updated,
we were unable to modify the write-once repository,
so we were forced to bump the version number.
This is why all the 3.6 cadence release items are labelled as "3.6.3".
So 3.6.3 is the first release of the 3.6.x version.
Apologies for the confusion.

## What's new in Android
<!--more-->

* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Add environment variable `BUILD_MULTIPLE_APKS` for splitting **APK**s based on architecture
* [CB-7410](https://issues.apache.org/jira/browse/CB-7410) Add whitelist entries to get `iframe`/**GoogleMaps** working
* [CB-7291](https://issues.apache.org/jira/browse/CB-7291) Add `external-launch-whitelist` and use it for filtering intent launches
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Work-in-progress gradle support
* [CB-7325](https://issues.apache.org/jira/browse/CB-7325) Fix error message in `android_sdk_version.js` when missing SDK on Windows
* [CB-7335](https://issues.apache.org/jira/browse/CB-7335) Add a `.gitignore` to android project template
* [CB-7330](https://issues.apache.org/jira/browse/CB-7330) Don't run `android update` during creation
* [CB-7321](https://issues.apache.org/jira/browse/CB-7321) Don't require `ant` for `create` script
* [CB-7044](https://issues.apache.org/jira/browse/CB-7044), [CB-7299](https://issues.apache.org/jira/browse/CB-7299) Fix up `PATH` problems when possible
* [CB-7261](https://issues.apache.org/jira/browse/CB-7261) Fix `setNativeToJsBridgeMode` sometimes crashing when switching to `ONLINE_EVENT`
* [CB-7265](https://issues.apache.org/jira/browse/CB-7265) Fix crash when navigating to custom protocol (introduced in `3.5.1`)
* Filter out non-launchable **intents**
* Extend whitelist to handle **URL**s without `//` chars
* [CB-7172](https://issues.apache.org/jira/browse/CB-7172) Force window to have focus after resume
* [CB-7018](https://issues.apache.org/jira/browse/CB-7018) Fix `setButtonPlumbedToJs` never un-listening
* `@Deprecate` methods of `PluginManager` that were never meant to be public
* Move plugin instantiation and instance storing logic `PluginEntry`->`PluginManager`
* Update to check for **Google Glass** APIs
* Fix for `android` not being in `PATH` check on Windows
* Tweak log messages in `CordovaBridge` with bridgeSecret is wrong
* Add `node_module` licenses to `LICENSE`
* Provide `CordovaPlugin` with `CordovaPreferences`. Add new `Plugin.initialize()`
* Convert usages of `Config.`* to use the non-static versions
* Change `getProperty` -> `prefs.get*` within `CordovaActivity`
* Move registration of App plugin from `config.xml` -> code
* Make `setWebViewClient` an override instead of an overload.
* Refactor: Use `ConfigXmlParser` in activity. Adds `CordovaWebView.init()`
* Deprecate some convenience methods on `CordovaActivity`
* Refactor: Move `url-filter` information into `PluginEntry`
* Don't re-parse `config.xml` in `onResume`
* Move handling of `Fullscreen` preference to `CordovaActivity`
* Delete `CB-3064: The errorUrl is...` log message left over from debugging presumably
* Refactor `Config` into `ConfigXmlParser`, `CordovaPreferences`
* Delete Location-change JS->Native bridge mode
* [CB-5988](https://issues.apache.org/jira/browse/CB-5988) Allow `exec()` only from *file*: or start-up *URL*'s domain
* [CB-6761](https://issues.apache.org/jira/browse/CB-6761) Fix native->JS bridge ceasing to fire when page changes and online is set to false and the JS loads quickly
* [CB-7018](https://issues.apache.org/jira/browse/CB-7018) Clean up and deprecation of some button-related functions
* [CB-7017](https://issues.apache.org/jira/browse/CB-7017) Fix `onload=true` being set on all subsequent plugins
* [CB-5971](https://issues.apache.org/jira/browse/CB-5971) Fix package / project validation
* Delete explicit `activity.finish()` in back button handling. No change in behaviour
* [CB-4404](https://issues.apache.org/jira/browse/CB-4404) Changing where `android:windowSoftInputMode` is in the manifest so it works
* Add documentation referencing other implementation
* [CB-6851](https://issues.apache.org/jira/browse/CB-6851) Deprecate `WebView.sendJavascript()`
* [CB-6876](https://issues.apache.org/jira/browse/CB-6876) Show the correct executable name
* [CB-6860](https://issues.apache.org/jira/browse/CB-6860) Add `activity_name` and `launcher_name` to `AndroidManifest.xml` & `strings.xml`
* Add a comment to `custom_rules.xml` saying why we move `AndroidManifest.xml`
* [CB-6784](https://issues.apache.org/jira/browse/CB-6784) Add missing licenses
* Revert `defaults.xml: Add AndroidLaunchMode preference`
* [CB-6315](https://issues.apache.org/jira/browse/CB-6315) Wrapping this so it runs on the UI thread
* [CB-6723](https://issues.apache.org/jira/browse/CB-6723) Update package name for **Robotium**
* [CB-6707](https://issues.apache.org/jira/browse/CB-6707) Update `minSdkVersion` to `10` consistently
* [CB-5652](https://issues.apache.org/jira/browse/CB-5652) Make visible cordova version



## What's new in iOS

* Updated default template
* [CB-7432](https://issues.apache.org/jira/browse/CB-7432) Version script should be updated by `coho` at release time
* [CB-5535](https://issues.apache.org/jira/browse/CB-5535) Ignore unused arguments in `bin/create` (e.g `--arc`), remove `--arc` references in `bin/create`
* [CB-6897](https://issues.apache.org/jira/browse/CB-6897) `nil` `callbackId` in `isValidCallbackId()` causes regex match to throw exception
* [CB-6897](https://issues.apache.org/jira/browse/CB-6897) Added unit test
* [CB-7169](https://issues.apache.org/jira/browse/CB-7169) Fix `__PROJECT_NAME__` replacing code in `create` script
* Remove trailing whitespace from project template's `.plist`, `.pch`
* [CB-7187](https://issues.apache.org/jira/browse/CB-7187) Delete `CDVShared.m` & remove dependency on `CoreLocation`
* Fix warning in `MainViewController.m` (spurious semi-colon)
* [CB-7162](https://issues.apache.org/jira/browse/CB-7162) `pre-commit` hook can't find `uncrustify` in path in Git GUI apps
* [CB-7134](https://issues.apache.org/jira/browse/CB-7134) Deprecate `CDVPluginResult` methods
* [CB-7043](https://issues.apache.org/jira/browse/CB-7043) Fix property `statusCode` of `CDVHTTPURLResponse` conflict with superclass property `statusCode` of `NSHTTPURLResponse` (**iOS** `8`)
* [CB-6165](https://issues.apache.org/jira/browse/CB-6165) Removing the `"OK"` String from success callback
* Update version of **NSData+Base64** to get a more normal license on it
* Minor uncrustification of a few files
* Update `LICENSE` to include **shelljs**'s license
* Remove `LICENSE` entries for files that we no longer use
* [CB-6579](https://issues.apache.org/jira/browse/CB-6579) Update deprecation to use `CDV_DEPRECATED` macro
* [CB-6998](https://issues.apache.org/jira/browse/CB-6998) Remove `CDVCommandDelegate::execute` deprecated call (deprecated since `2.2`)
* [CB-6997](https://issues.apache.org/jira/browse/CB-6997) Deprecate obsolete `CDVPlugin` methods
* Fix minor grammar in `CDVLocalStorage` **iCloud** warning
* [CB-6785](https://issues.apache.org/jira/browse/CB-6785) Add license to `CONTRIBUTING.md`
* [CB-6729](https://issues.apache.org/jira/browse/CB-6729) Update `printDeprecationNotice` to new name, and new warning for **iOS** < `6.0`
* [CB-5651](https://issues.apache.org/jira/browse/CB-5651) Make visible the version of the Cordova native lib




## What's new in Windows Phone 8

* Fix template def missing files
* Remove unwanted slashes and handle Exceptions
* Add **AppVeyor** badge
* [CB-7368](https://issues.apache.org/jira/browse/CB-7368) `--archs="x86"` now produces correct binaries
* [CB-7341](https://issues.apache.org/jira/browse/CB-7341) Port tooling/platform scripts from **WSH** to **NodeJS**
* Adding testing to the workflow
* [CB-6763](https://issues.apache.org/jira/browse/CB-6763) Fixes issue when multiple simultaneous requests are sent
* [CB-4655](https://issues.apache.org/jira/browse/CB-4655) Default native project template should be overridable at project creation time
* [CB-7305](https://issues.apache.org/jira/browse/CB-7305) Remove trailing slash from dest
* Cleanup file, remove commented out stuff after testing it
* Update instructions minus `createTemplates` stuff
* Fix intermittent issue with invalid app manifest because of xml commented apache header
* `create` needs to copy+rename the `defaults.xml` file for projects created outside the cordova-cli
* Removing outdated/unused tooling scripts
* Move `createTemplates` scripts (they will live undoc'd for a while)
* Move common items to their rightful home
* [CB-7028](https://issues.apache.org/jira/browse/CB-7028) Fixed memory leak in **WP** with plugins
* Use wildcard for contents of `www/` folder
* Small fix for spaces in path
* `createTemplates` script copies `defaults.xml`->`config.xml`
* [CB-5049](https://issues.apache.org/jira/browse/CB-5049) Create `defaults.xml` that contains platform `config.xml` defaults
* [CB-6788](https://issues.apache.org/jira/browse/CB-6788) Fix header licenses (**Apache RAT** report)
* [CB-7060](https://issues.apache.org/jira/browse/CB-7060) Fix large project build performance issue
* Adds support for chip architectures to `run` command
* [CB-6924](https://issues.apache.org/jira/browse/CB-6924) Fixed memory leak in WP page navigation
* [CB-6939](https://issues.apache.org/jira/browse/CB-6939) Replace dash chars in package name and validate it
* Fixes handling of UTF-8 encoded project files
* Added list of supported architectures in help text
* Adds support for target architectures to build command
* Escapes paths in `target()` function
* add license header to all bat files, and echo off so we don't see the goto output
* [CB-6788](https://issues.apache.org/jira/browse/CB-6788) Add license header
* [CB-6775](https://issues.apache.org/jira/browse/CB-6775) Added support for autoload, splashscreen uses this
* [CB-5653](https://issues.apache.org/jira/browse/CB-5653) Make visible cordova version
* **WP8.1** and the **IE11 WebBrowser** control do not support `execScript`, moving to `eval`
* [CB-6732](https://issues.apache.org/jira/browse/CB-6732) Fix `MSBuild 64 bit is not supported` build error
* [CB-6341](https://issues.apache.org/jira/browse/CB-6341) Remove requirement to have `MSBuild` in the `%PATH%`
* [CB-6676](https://issues.apache.org/jira/browse/CB-6676) Allow extra params to `build`/`run` and ignore them
* [CB-6685](https://issues.apache.org/jira/browse/CB-6685) \[3.5.0rc\] Build error: `Command failed with exit code 2`
* Adds `-wait` flag to `CordovaDeploy`. Removes unnecessary `Program` class
* **WP7** Goodbye, it has been fun. `;)`
* Apply `app-hello-world` update



## What's new in Windows

* [CB-7377](https://issues.apache.org/jira/browse/CB-7377) Removes unnecessary rules tracing which is also incorrectly handled by **PowerShell**
* Removed un-needed files, multiple `cordova.js` files can only cause confusion
* [CB-7377](https://issues.apache.org/jira/browse/CB-7377) Whitelist. Windows build error due to `invalid URI rules in config.xml`
* [CB-7333](https://issues.apache.org/jira/browse/CB-7333) Makes default platform template files overridable
* Add **AppVeyor** badge
* [CB-7129](https://issues.apache.org/jira/browse/CB-7129) **VS2012** solution now accepts `anycpu` target instead of `any cpu`
* [CB-7129](https://issues.apache.org/jira/browse/CB-7129) Fixes issue when project isn't built if **msbuild v12.0** is not found
* Updated repo `README`
* Add **AppVeyor** file for CI
* Add basic `npm` test of create+build project
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Reflect new switch name to project structure
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Changes switch name from `--store` to `--win`
* Moves `node_modules` to `bin` to correctly work under `npm`
* Adds missing `ExecutionPolicy` option for **PowerShell**
* Configurable target version for store and phone targets
* [CB-7129](https://issues.apache.org/jira/browse/CB-7129) Spellcheck
* Rewrite tooling/platform scripts from **WSH** to **NodeJS**
* [CB-7243](https://issues.apache.org/jira/browse/CB-7243) `VERSION` file is copied over in `create` platform script
* [CB-6699](https://issues.apache.org/jira/browse/CB-6699) Using wildcard `**` glob to include `www` folder items
* [CB-7144](https://issues.apache.org/jira/browse/CB-7144) `run` fails if replace default certificate
* [CB-6787](https://issues.apache.org/jira/browse/CB-6787) Fix header licenses (**Apache RAT** report)
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Support for new splash screen and icon images
* Fixes potential perf issue inside `exec_verbose` method
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Fixes deploy error when `--nobuild` option specified
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Replaces new template icons and splash screens
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Fixes deploy error on **WP8.1** emulator
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Fixes `run`/`emulate` error when it runs for the first time
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Fixes deploy when target type is not specified
* Adds support for build archs to `run` command  + small cleanup and refactoring  + fix **jshint** issues
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Add support for **Windows Universal** apps (**Windows 8.1** and **WP 8.1**)
* Removed **Windows7** which is now in its own branch
* Added list of supported architectures in help text
* Adds support for target architectures to build command
* [CB-6686](https://issues.apache.org/jira/browse/CB-6686) \[3.5.0rc\] Build  error if path contains whitespaces
* [CB-6684](https://issues.apache.org/jira/browse/CB-6684) \[3.5.0rc\] Splash screen setting breaks the build
* [CB-6787](https://issues.apache.org/jira/browse/CB-6787) Add license to `windows8/CONTRIBUTING.md`
* [CB-6684](https://issues.apache.org/jira/browse/CB-6684) \[3.5.0rc\] Splash screen setting breaks the build
* [CB-6686](https://issues.apache.org/jira/browse/CB-6686) \[3.5.0rc\] Build  error if path contains whitespaces


## What's new in BlackBerry 10

* [CB-7409](https://issues.apache.org/jira/browse/CB-7409) Update `CORDOVA_HOME_DIR` based on `npm_cache`
* [CB-7411](https://issues.apache.org/jira/browse/CB-7411) Make version in version script easier to replace by `coho`
* [CB-7336](https://issues.apache.org/jira/browse/CB-7336) Add `bundledDependencies` to `package.json`
* [CB-7211](https://issues.apache.org/jira/browse/CB-7211) **jshint**: force to see all errors
* [CB-7210](https://issues.apache.org/jira/browse/CB-7210) Cleanup `create` remove `clean`/`copyJavascript`
* [CB-7250](https://issues.apache.org/jira/browse/CB-7250) Test/cordova/integration/target use private home
* [CB-7209](https://issues.apache.org/jira/browse/CB-7209) Improve tests including adding parallelism support
* [CB-7186](https://issues.apache.org/jira/browse/CB-7186) Fix up packager-validator tests to indicate signing
* [CB-7186](https://issues.apache.org/jira/browse/CB-7186) `--no-signing` will be ignored if `--buildId` is set
* Update package name to match convention (`cordova-`\[platform name\])
* [CB-5815](https://issues.apache.org/jira/browse/CB-5815) Fix `cordova` not defined when pausing w/o `cordova.js` included
* [CB-7119](https://issues.apache.org/jira/browse/CB-7119) Fix `cordova run --target xxx` dies if `blackberry10.json` is empty
* [CB-7087](https://issues.apache.org/jira/browse/CB-7087) Retire `blackberry10/` directory
* [CB-6492](https://issues.apache.org/jira/browse/CB-6492) Fix `AppData` hint for **wXP**
* [CB-7036](https://issues.apache.org/jira/browse/CB-7036) Make `npm test` work again (using `grunt` instead of `jake`)
* [CB-7025](https://issues.apache.org/jira/browse/CB-7025) Report platform update
* [CB-6968](https://issues.apache.org/jira/browse/CB-6968) Fix bashism (`source`) in `update` script and `bb10-ndk-version`
* [CB-6934](https://issues.apache.org/jira/browse/CB-6934) `run` should complain about target w/o ip before password
* [CB-6925](https://issues.apache.org/jira/browse/CB-6925) Simulator detection: fail gracefully w/ no DHCP leases
* [CB-6904](https://issues.apache.org/jira/browse/CB-6904) Improve Markdown in `README.md`
* [CB-5436](https://issues.apache.org/jira/browse/CB-5436) Update `defaults.xml` and `config.xml` configuration reference
* [CB-6850](https://issues.apache.org/jira/browse/CB-6850) Use `path.join()` for `blackberry10debugtoken.bar` warning
* [CB-6757](https://issues.apache.org/jira/browse/CB-6757) Provide useful hint when simulator does not seem to know its IP
* [CB-5654](https://issues.apache.org/jira/browse/CB-5654) Log 'native' Cordova version during framework bootstrap
* [CB-6786](https://issues.apache.org/jira/browse/CB-6786) Add license to `CONTRIBUTING.md`
* [CB-6730](https://issues.apache.org/jira/browse/CB-6730) Tweak whitelist URI parsing to fix whitelist issues with `@2x` resource naming
* [CB-6554](https://issues.apache.org/jira/browse/CB-6554) Fix malformed json file


## What's new in Firefox OS

* Added `bundledDependencies` to `package.json`
* Added `console.log` to `version` script
* Remove hardcoded cordova version
* Fixing error on new CLI/LIB: `cp: no such file or directory: /Users/rodrigo/mozilla/cordova/delme/platforms/firefoxos/www/cordova.js`
* Add `clean.bat`
* [CB-7016](https://issues.apache.org/jira/browse/CB-7016) `.zip` created by build has unnecessary `./` folder on all files
* `cordova.js` needs to be copied to platform `www`
* Update `Readme`
* Remove `<!-- and -->`
* Update header licenses
* Delete `foo` file
* Update project
* Update defaults
* Add icons
* Removing unused template
* [CB-6816](https://issues.apache.org/jira/browse/CB-6816) Add license to `CONTRIBUTING.md`
* Simplifies build
* [CB-5751](https://issues.apache.org/jira/browse/CB-5751) Fix **FirefoxOS** build issue

## What's new in Ubuntu (touch)

* Added missing licenses
* `bin/create`: create `www`
* Switch to incremental build
* Set `policy_version` in `apparmor.json` based on framework version
* Remove `-flto` from compiler flags
* Change default to `ubuntu-sdk-14.04`
* Plugin could specify additional build dependency
* Use different compiler flags for debug/release build
* Fix build problem with `ubuntu-sdk-14.04`
* `bin/build/build`: integrate with `click-reviewers-tools`
* `bin/build/build`: check `chroot` env before build
* `bin/build/build`, `bin/build/run`: add `--framework` option
* Add emulator support
* Add support for non-arm based **Ubuntu Touch** devices
* `CordovaViewInternal`: add `overrideScheme`
* `cplugin`: add `onAppLoaded`
* [CB-6818](https://issues.apache.org/jira/browse/CB-6818) Add license for `CONTRIBUTING.md`

## What's new in Amazon FireOS

* Updated `cordova.js` in tests
* [CB-7291](https://issues.apache.org/jira/browse/CB-7291) Add `external-launch-whitelist` and use it for filtering intent launches
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Ensure that **JAR** files in `libs` directory are included
* [CB-7410](https://issues.apache.org/jira/browse/CB-7410) Add whitelist entries to get `iframe`/**GoogleMaps** working
* [CB-7291](https://issues.apache.org/jira/browse/CB-7291) Propagate change in method signature to the native tests
* [CB-7291](https://issues.apache.org/jira/browse/CB-7291) Restrict meaning of `*` in internal whitelist to just *http* and *https*
* [CB-7291](https://issues.apache.org/jira/browse/CB-7291) Only add *file*, *content* and *data* **URL**s to internal whitelist
* [CB-7291](https://issues.apache.org/jira/browse/CB-7291) Add defaults to external whitelist
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Read `project.properties` to configure **gradle** libraries
* [CB-7325](https://issues.apache.org/jira/browse/CB-7325) Fix error message in `android_sdk_version.js` when missing SDK on Windows
* [CB-7335](https://issues.apache.org/jira/browse/CB-7335) Add a `.gitignore` to android project template
* [CB-7330](https://issues.apache.org/jira/browse/CB-7330) Don't run `android update` during creation
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Add `gradle clean` command (plus some code cleanup)
* Fix for `AmazonWebView`
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Copy gradle wrapper in `build` instead of `create`
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Add `.gradle` template files for `update` as well as `create`
* [CB-7044](https://issues.apache.org/jira/browse/CB-7044) Add `JAVA_HOME` when not set. Be stricter about `ANDROID_HOME`
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Speed up gradle building (incremental builds go from 10s -> 1.5s for me)
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Copy Gradle wrapper from Android SDK rather than bundling a JAR
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Add which to checked-in node_modules
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Add option to build and install with gradle
* [CB-3445](https://issues.apache.org/jira/browse/CB-3445) Add an initial set of Gradle build scripts
* [CB-7321](https://issues.apache.org/jira/browse/CB-7321) Don't require `ant` for `create` script
* [CB-7044](https://issues.apache.org/jira/browse/CB-7044), [CB-7299](https://issues.apache.org/jira/browse/CB-7299) Fix up `PATH` problems when possible
* Change in test's `AndroidManifest.xml` needed for the test to run properly
* Adding tests related to `3.5.1`
* [CB-7261](https://issues.apache.org/jira/browse/CB-7261) Fix `setNativeToJsBridgeMode` sometimes crashing when switching to `ONLINE_EVENT`
* [CB-7265](https://issues.apache.org/jira/browse/CB-7265) Fix crash when navigating to custom protocol (introduced in `3.5.1`)
* Filter out non-launchable **intents**
* Handle unsupported protocol errors in webview better
* Amazon related fixes after uplevel
* [CB-7238](https://issues.apache.org/jira/browse/CB-7238) I should have collapsed this, but `Config.init()` must go before the creation of `CordovaWebView`
* [CB-7238](https://issues.apache.org/jira/browse/CB-7238) Minor band-aid to get tests running again, this has to go away before `3.6.0` is released, since this is an API change
* Extend whitelist to handle **URL**s without `//` chars
* [CB-7172](https://issues.apache.org/jira/browse/CB-7172) Force window to have focus after resume
* [CB-7159](https://issues.apache.org/jira/browse/CB-7159) Set background color of webView as well as its parent
* [CB-7018](https://issues.apache.org/jira/browse/CB-7018) Fix `setButtonPlumbedToJs` never un-listening
* `@Deprecate` methods of `PluginManager` that were never meant to be public
* Move plugin instantiation and instance storing logic `PluginEntry`->`PluginManager`
* Fix broken unit test due to missing `Config.init()` call
* Update to check for **Google Glass** APIs
* Fix for `android` not being in `PATH` check on Windows
* Displaying error when regex does not match
* Tweak `CordovaPlugin.initialize` method to be less deprecated
* Un-deprecate `CordovaActivity.init()` - it's needed to tweak prefs in `onCreate`
* Tweak log messages in `CordovaBridge` with bridgeSecret is wrong
* Backport `CordovaBridge` from 4.0.x -> master
* Update unit tests to not use most deprecated things (e.g. **DroidGap**)
* Add non-String overloads for `CordovaPreferences.set()`
* Make `CordovaWebview` resilient to `init()` not being called (for backwards-compatibility)
* Add `node_module` licenses to `LICENSE`
* Provide `CordovaPlugin` with `CordovaPreferences`. Add new `Plugin.initialize()`
* Convert usages of `Config.`* to use the non-static versions
* Change `getProperty` -> `prefs.get*` within `CordovaActivity`
* Make `CordovaUriHelper` class package-private
* Fix `PluginManager.setPluginEntries` not removing old entries
* Move registration of App plugin from `config.xml` -> code
* Make `setWebViewClient` an override instead of an overload. Delete Location-change JS->Native bridge mode (missed some of it)
* [CB-4404](https://issues.apache.org/jira/browse/CB-4404) Revert setting `android:windowSoftInputMode` to `adjustPan`
* Refactor: Use `ConfigXmlParser` in activity. Adds `CordovaWebView.init()`
* Deprecate some convenience methods on `CordovaActivity`
* Fix `CordovaPreferences` not correctly parsing hex values (`valueOf`->`decode`)
* Refactor: Move `url-filter` information into `PluginEntry`
* Don't re-parse `config.xml` in `onResume`
* Move handling of `Fullscreen` preference to `CordovaActivity`
* Delete dead code from `CordovaActivity`
* Update `.classpath` to make **Eclipse** happy (just re-orders one line)
* Delete `CB-3064: The errorUrl is...` log message left over from debugging presumably
* Refactor `Config` into `ConfigXmlParser`, `CordovaPreferences`
* Delete Location-change JS->Native bridge mode
* [CB-5988](https://issues.apache.org/jira/browse/CB-5988) Allow `exec()` only from *file*: or start-up *URL*'s domain
* [CB-6761](https://issues.apache.org/jira/browse/CB-6761) Fix native->JS bridge ceasing to fire when page changes and online is set to false and the JS loads quickly
* Update the `errorurl` to no longer use **intents**
* Refactoring the URI handling on Cordova, removing dead code
* [CB-7018](https://issues.apache.org/jira/browse/CB-7018) Clean up and deprecation of some button-related functions
* [CB-7017](https://issues.apache.org/jira/browse/CB-7017) Fix onload=true being set on all subsequent plugins
* [CB-5971](https://issues.apache.org/jira/browse/CB-5971) Fix package / project validation
* [CB-5971](https://issues.apache.org/jira/browse/CB-5971) Add unit tests to cordova-android
* [CB-5971](https://issues.apache.org/jira/browse/CB-5971) Factor out package/project name validation logic
* Delete explicit `activity.finish()` in back button handling. No change in behaviour
* [CB-4404](https://issues.apache.org/jira/browse/CB-4404) Changing where `android:windowSoftInputMode` is in the manifest so it works
* Add documentation referencing other implementation
* [CB-6851](https://issues.apache.org/jira/browse/CB-6851) Deprecate `WebView.sendJavascript()`
* [CB-6876](https://issues.apache.org/jira/browse/CB-6876) Show the correct executable name
* [CB-6876](https://issues.apache.org/jira/browse/CB-6876) Fix the "print usage"
* Trivial spelling fix in comments when reading `CordovaResourceApi`
* [CB-6818](https://issues.apache.org/jira/browse/CB-6818) I want to remove this code, because Square didn't do their headers properly
* [CB-6860](https://issues.apache.org/jira/browse/CB-6860) Add `activity_name` and `launcher_name` to `AndroidManifest.xml` & `strings.xml`
* Add a comment to `custom_rules.xml` saying why we move `AndroidManifest.xml`
* Remove +x from `README.md`
* [CB-6784](https://issues.apache.org/jira/browse/CB-6784) Add missing licenses
* Revert `defaults.xml: Add AndroidLaunchMode preference`
* [CB-6315](https://issues.apache.org/jira/browse/CB-6315) Wrapping this so it runs on the UI thread
* [CB-6723](https://issues.apache.org/jira/browse/CB-6723) Update package name for **Robotium**
* [CB-6707](https://issues.apache.org/jira/browse/CB-6707) Update `minSdkVersion` to `10` consistently
* [CB-5652](https://issues.apache.org/jira/browse/CB-5652) Make visible cordova version
* [CB-6392](https://issues.apache.org/jira/browse/CB-6392) `create.js` updated to create `libs` folder before copying it to the project's platform folder
* [CB-6392](https://issues.apache.org/jira/browse/CB-6392) Checking for `awv_interface.jar` existance is moved to `create_project()`
* [CB-6392](https://issues.apache.org/jira/browse/CB-6392) `check_reqs.js` no longer checks for `awv_interface.jar`
* Fixing a typo which was sending the wrong string to plugins for js confirm dialogs
* [CB-6740](https://issues.apache.org/jira/browse/CB-6740) Cleanup error reporting when `AmazonWebView SDK` is not found; Updated create script to check commonlibs folder under `~/.cordova/lib`. If it doesn't exist create one and let user know. Error message updated. If exists copy it to specific release's `framework/libs` folder
* JS confirm DnD alert dialog in Cordova consumes all key events
* [CB-6818](https://issues.apache.org/jira/browse/CB-6818) Add license for `CONTRIBUTING.md`
* Updated release notes
* [CB-6644](https://issues.apache.org/jira/browse/CB-6644) Add a check for webview being null in template code Added a check and some comments to guide devs


## What's new in Cordova-CLI

* [CB-7355](https://issues.apache.org/jira/browse/CB-7355) Re added single test to test call through to cordova-lib cordova raw create
* [CB-7364](https://issues.apache.org/jira/browse/CB-7364) Remove duplicate logging initialization for cordova/plugman
* [CB-7363](https://issues.apache.org/jira/browse/CB-7363) Do not insist on precise version of cordova-lib
* [CB-7355](https://issues.apache.org/jira/browse/CB-7355) Removed create tests which test behaviour of downstream dependencies
* [CB-7358](https://issues.apache.org/jira/browse/CB-7358) Cli spec mocks console log to avoid polluting test output while testing
* [CB-7347](https://issues.apache.org/jira/browse/CB-7347) Document `cordova platform add /path/to` support
* [CB-7345](https://issues.apache.org/jira/browse/CB-7345) Add tests to validate documentation
* [CB-7345](https://issues.apache.org/jira/browse/CB-7345) Improve cli documentation
* Refactored test to make use of **jasmine**'s `toThrow` expectation
* Correct object referenced in tests
* Proper order of initializers, which indicates a bigger problem
* Moved custom www handling code to a separate function
* Basic tests and structure added to create spec
* Renamed cli create spec more sensibly
* Parse config json moved to a function
* Functional refactor of create with expected input from caller implemented
* Updated tests and cli to pass all tests
* Tracking cli create spec
* Initial commit of cli create command logic in its own file
* Added verbose mode initialization to set up event handlers
* Created `init` function to handle initialization of `underscore` and `nopt`
* Added **browserify** option `download_opts`
* [CB-7249](https://issues.apache.org/jira/browse/CB-7249) Cordova-cli documentation translation: cordova-cli
* [CB-7001](https://issues.apache.org/jira/browse/CB-7001) Added `--browserify` to help documentation
* [CB-6024](https://issues.apache.org/jira/browse/CB-6024) Document `--` for platform options
* Added `--browserify` flag to cli options
* [CB-7220](https://issues.apache.org/jira/browse/CB-7220) Support `cordova_lib.binname`
* [CB-7220](https://issues.apache.org/jira/browse/CB-7220) Split cordova help into per feature help files
* [CB-6756](https://issues.apache.org/jira/browse/CB-6756) Adds the `platforms` subcommand for `save` and `restore`
* [CB-7100](https://issues.apache.org/jira/browse/CB-7100) Use `npm` based **lazy-load** by default
* [CB-6127](https://issues.apache.org/jira/browse/CB-6127) Documentation translation
* Call `process.removeAllListeners()` in cli spec
* Add `--captureExceptions` flag to `jasmine`
* Pin `jasmine` to older version *temporarily*
* Fix [CB-7069](https://issues.apache.org/jira/browse/CB-7069) Copy-from & link-to custom uri -> url


## What's new in Cordova-Plugman

* [CB-7363](https://issues.apache.org/jira/browse/CB-7363) Do not insist on precise version of cordova-lib
* [CB-7362](https://issues.apache.org/jira/browse/CB-7362) Add `Please run npm install from this directory` code
* Remove `package.json`:`scripts.test`

## What's new in Cordova-Lib

* [CB-5535](https://issues.apache.org/jira/browse/CB-5535) Remove `--arc` from **iOS** platform creation args
* [CB-7416](https://issues.apache.org/jira/browse/CB-7416) Fixes file path reference when adding new source file
* [CB-7416](https://issues.apache.org/jira/browse/CB-7416) `HandleInstall` tests for `null` `platformTag`. removed uncalled `hasPlatformSection` from `PluginInfo.js`
* Remove use of `path.join` for `manifest.launch_path`
* [CB-7347](https://issues.apache.org/jira/browse/CB-7347) Improve cordova platform add `/path/to` handling
* [CB-7114](https://issues.apache.org/jira/browse/CB-7114) **Android** add support of min/max/target SDK to `config.xml`
* [CB-7118](https://issues.apache.org/jira/browse/CB-7118) Use updated version of `node-xcode`
* [CB-7118](https://issues.apache.org/jira/browse/CB-7118) **iOS** add `target-device` and `MinimumOSVersion` support to `config.xml`
* **Ubuntu** support incremental builds
* **Ubuntu** support `target-dir` for `resource-file`
* **Ubuntu** use `common.copyFile`
* **Ubuntu** check icon existence
* **FxOS** Make author url optional
* [CB-7142](https://issues.apache.org/jira/browse/CB-7142) Add `<variable>` to `<feature>` for `cordova plugin restore` command
* Set `git clone depth` to `10` for **Travis** to make it faster
* **Windows** update as per changed manifest file names
* [CB-6699](https://issues.apache.org/jira/browse/CB-6699) Include files from `www` folder via single element (use `**` glob pattern)
* Allow plugin modules to be `.json` files
* Taking care of dashes in `amazon-fireos` platform name
* Fix link/copy parent check for **Windows**
* Fix error in comments for munge functions
* Add link to **BuildBot** at `ci.cordova.io` in `README`
* [CB-7255](https://issues.apache.org/jira/browse/CB-7255) Fixed writing plist unescaped
* Style fixes - white space only
* Add **JSCS** config file
* [CB-7228](https://issues.apache.org/jira/browse/CB-7228) Fixed issue with `cordova prepare --browserify`
* [CB-7001](https://issues.apache.org/jira/browse/CB-7001) Create a `--browserify` option for run action
* [CB-7228](https://issues.apache.org/jira/browse/CB-7228) Cordova prepare `--browserify` runs on all installed plugins
* [CB-7001](https://issues.apache.org/jira/browse/CB-7001) Create a `--browserify` option for run action
* [CB-7228](https://issues.apache.org/jira/browse/CB-7228) Cordova prepare `--browserify` runs on all installed plugins
* [CB-7190](https://issues.apache.org/jira/browse/CB-7190) Add **browserify** support in `cordova-lib`/`cordova-cli`
* [CB-7234](https://issues.apache.org/jira/browse/CB-7234) Added better outputs for plugin registry workflows
* [CB-7100](https://issues.apache.org/jira/browse/CB-7100) Use `npm` based **lazy-load** by default
* [CB-7091](https://issues.apache.org/jira/browse/CB-7091) Remove `check_requirements()` functions from platform parsers
* [CB-7140](https://issues.apache.org/jira/browse/CB-7140) Check plugin versions in local search path
* [CB-7203](https://issues.apache.org/jira/browse/CB-7203) `IsRelativePath` needs to pass path through
* [CB-7199](https://issues.apache.org/jira/browse/CB-7199) Control `git`/`npm` using `platform.js`
* [CB-6756](https://issues.apache.org/jira/browse/CB-6756) Adds `save` and `restore` command for platforms
* [CB-7132](https://issues.apache.org/jira/browse/CB-7132) Fix regression regarding default resources
* [CB-7187](https://issues.apache.org/jira/browse/CB-7187) Make `CoreLocation` a required library only for **cordova-ios** `< 3.6.0`
* Add **AppVeyor** badge to `README`
* Add **Travis** and **npm** badges to `README.md`
* Fix test cordova/lazy_load spec on **Windows**
* Fix plugman/install spec
* Build configuration for **AppVeyor**
* Build configurations for **Travis**
* [CB-7124](https://issues.apache.org/jira/browse/CB-7124) Wrap the cordova platform string in `Platform` object
* [CB-7140](https://issues.apache.org/jira/browse/CB-7140) Switch to using `PluginInfo` in `plugman/fetch.js`
* Minor style fixes in `fetch.js`
* [CB-7078](https://issues.apache.org/jira/browse/CB-7078) Disable `serve.spec.js`
* [CB-6512](https://issues.apache.org/jira/browse/CB-6512) Platform add `<path>` was using wrong `www/cordova.js`
* [CB-7083](https://issues.apache.org/jira/browse/CB-7083) Missing `SDKReference` support on **WP**
* [CB-6874](https://issues.apache.org/jira/browse/CB-6874) Consolidate `<Content>` tag additions into 1 `ItemGroup`
* [CB-7100](https://issues.apache.org/jira/browse/CB-7100) Use `npm` based **lazy-load** by default
* [CB-7091](https://issues.apache.org/jira/browse/CB-7091) Remove `check_requirements()` funcs from platform parsers
* [CB-7091](https://issues.apache.org/jira/browse/CB-7091) Don't call `check_requirements` during platform add
* [CB-7087](https://issues.apache.org/jira/browse/CB-7087) Retire `blackberry10/` directory
* [CB-6776](https://issues.apache.org/jira/browse/CB-6776) Fix uri/url renaming bug
* Remove `npm-shrinkwrap.json`

## What's new in Cordova JS ##

* Checking for Windows style path
* Better handling of all `modulemapper.clobbers` replacements
* Fixed **browserify** `onDeviceReady` event not firing on the browser
* Removed check for `c:` and added check for **Windows** platform
* Fixed Windows path issue when trying to set `navigator.app` in `cordova.js`
* [CB-7349](https://issues.apache.org/jira/browse/CB-7349) Tell users to run `npm install`
* Upleveled **amazon-fireos** changes
* [CB-870](https://issues.apache.org/jira/browse/CB-870) **Android** Add volume button event support
* **FxOS** Remove hardcoded cordova version
* [CB-6764](https://issues.apache.org/jira/browse/CB-6764) Fix `findCordovaPath()` detecting `notcordova.js` as `cordova.js`
* [CB-6976](https://issues.apache.org/jira/browse/CB-6976) Add support for **Windows Universal** apps (**Windows 8.1** and **WP 8.1**)
* [CB-6714](https://issues.apache.org/jira/browse/CB-6714) Base **webOS** `3.x` Cordova implementation
* **Android** Delete Location-change JS->Native bridge mode
* [CB-5988](https://issues.apache.org/jira/browse/CB-5988) **Android** Allow `exec()` only from *file*: or start-up *URL*'s domain
* [CB-7034](https://issues.apache.org/jira/browse/CB-7034) **BlackBerry10** Add error handling to exec makeSyncCall
* [CB-6983](https://issues.apache.org/jira/browse/CB-6983) Misleading debug statement
* [CB-6884](https://issues.apache.org/jira/browse/CB-6884) Fixed js callbacks not firing using `WKWebView` Cordova bridge
* [CB-6884](https://issues.apache.org/jira/browse/CB-6884) Added `WKWebView` Cordova bridge
* [CB-6863](https://issues.apache.org/jira/browse/CB-6863) Default Cordova bridge broken due to replacing `window.navigator` (**iOS** 8)
* [CB-6867](https://issues.apache.org/jira/browse/CB-6867) **WP8**, **Windows8** allow empty args
* Adding `cordova.require`
* Adding transform for File plugin
* [CB-6792](https://issues.apache.org/jira/browse/CB-6792) Add license to `CONTRIBUTING.md`
* Removed contacts hack, added regex to handle geolocation
* Fix some old references in the `README.md`
* Updating transform to support bs paths
* Updating transform for **iOS** contacts
* Moving to `TreeTransformer` and adding a quick substitution for **Android** `navigator.app` clobber
* Changed id to **amazon-fireos**
* Fix broken unit tests with **Node** v0.11.13+ *hack*
* Disable `urlutil` tests under **jsdom** & set **jsdom** to `file:` to avoid hitting network

## Plugin versions tested with this release

* cordova-plugin-battery-status: 0.2.10
* cordova-plugin-camera: 0.3.1
* cordova-plugin-console: 0.2.10
* cordova-plugin-contacts: 0.2.12
* cordova-plugin-device: 0.2.11
* cordova-plugin-device-motion: 0.2.9
* cordova-plugin-device-orientation: 0.3.8
* cordova-plugin-dialogs: 0.2.9
* cordova-plugin-file: 1.3.0
* cordova-plugin-file-transfer: 0.4.5
* cordova-plugin-geolocation: 0.3.9
* cordova-plugin-globalization: 0.3.0
* cordova-plugin-inappbrowser: 0.5.1
* cordova-plugin-media: 0.2.12
* cordova-plugin-media-capture: 0.3.2
* cordova-plugin-network-information: 0.2.11
* cordova-plugin-splashscreen: 0.3.2
* cordova-plugin-statusbar: 0.1.7
* cordova-plugin-vibration: 0.3.10
